@@ -59,6 +59,10 @@ class Author(unicode):
             elif parts[i] == '.':
                 parts[i-1] += parts[i]
                 del parts[i]
+            elif re.match(r'[A-Z]{2,}', parts[i]):
+                expanded = [p + '.' for p in parts[i]]
+                parts[i:i+1] = expanded
+                i += len(expanded)
             else:
                 i += 1
 
@@ -120,3 +124,22 @@ class Author(unicode):
                 else:
                     return False
         return True
+
+    def find_best_match(self, authors):
+        authors = set(authors)
+
+        for a in authors:
+            if a == self:
+                return a
+
+        candidates = [a for a in authors if set(self.chunks) & set(a.chunks)]
+
+        if len(candidates) == 1:
+            # Ok, we found it
+            return candidates[0]
+        elif candidates:
+            # Multiple matches left
+            pass
+        else:
+            # Zero matches
+            pass
